@@ -1,6 +1,6 @@
 /****************************************************************************
  *
- * $Id: simulateCircle2DCamVelocity.cpp 4574 2014-01-09 08:48:51Z fspindle $
+ * $Id: simulateCircle2DCamVelocity.cpp 5263 2015-02-04 13:43:25Z fspindle $
  *
  * This file is part of the ViSP software.
  * Copyright (C) 2005 - 2014 by INRIA. All rights reserved.
@@ -63,9 +63,6 @@
 #include <visp/vpCameraParameters.h>
 #include <visp/vpTime.h>
 #include <visp/vpSimulator.h>
-
-
-
 #include <visp/vpMath.h>
 #include <visp/vpHomogeneousMatrix.h>
 #include <visp/vpFeatureEllipse.h>
@@ -76,11 +73,9 @@
 #include <visp/vpParseArgv.h>
 #include <visp/vpIoTools.h>
 
-
 #define GETOPTARGS	"cdi:h"
 #define SAVE 0
 
-
 /*!
 
 Print the program options.
@@ -194,101 +189,76 @@ void *mainLoop (void *_simu)
 
     float sampling_time = 0.040f; // Sampling period in second
     robot.setSamplingTime(sampling_time);
+    robot.setMaxTranslationVelocity(4.);
 
-    /*      std::cout << std::endl ;
-      std::cout << "-----------------------" << std::endl ;
-      std::cout << " Test program for vpServo "  <<std::endl ;
-      std::cout << " Simulation " << std::endl ;
-      std::cout << " task : servo a circle " << std::endl ;
-      std::cout << "-----------------------" << std::endl ;
-      std::cout << std::endl ;
-*/
-
-    vpTRACE("sets the initial camera location " ) ;
-
-
+    // Sets the initial camera location
     robot.setPosition(cMo) ;
     simu->setCameraPosition(cMo) ;
 
-
     if (pos==1)  cMod[2][3] = 0.32 ;
 
-    vpTRACE("sets the circle coordinates in the world frame "  ) ;
+    // Sets the circle coordinates in the world frame
     vpCircle circle ;
     circle.setWorldCoordinates(0,0,1,0,0,0,0.1) ;
 
-    vpTRACE("sets the desired position of the visual feature ") ;
+    // Sets the desired position of the visual feature
     vpFeatureEllipse pd ;
     circle.track(cMod) ;
     vpFeatureBuilder::create(pd,circle)  ;
 
-    vpTRACE("project : computes  the circle coordinates in the camera frame and its 2D coordinates"  ) ;
-
-    vpTRACE("sets the current position of the visual feature ") ;
+    // Project : computes the circle coordinates in the camera frame and its 2D coordinates
+    // Sets the current position of the visual feature
     vpFeatureEllipse p ;
     circle.track(cMo) ;
     vpFeatureBuilder::create(p,circle)  ;
 
-    vpTRACE("define the task") ;
-    vpTRACE("\t we want an eye-in-hand control law") ;
-    vpTRACE("\t robot is controlled in the camera frame") ;
+    // Define the task
+    // We want an eye-in-hand control law
+    // Robot is controlled in the camera frame
     task.setServo(vpServo::EYEINHAND_CAMERA) ;
     task.setInteractionMatrixType(vpServo::CURRENT) ;
 
-    vpTRACE("\t we want to see a circle on a circle..") ;
+    // We want to see a circle on a circle
     std::cout << std::endl ;
     task.addFeature(p,pd) ;
 
-    vpTRACE("\t set the gain") ;
-
+    // Set the gain
     task.setLambda(1.0) ;
-    //       if (pos==2)
-    // 	task.setLambda(0.0251) ;
-    //       else
-    // 	task.setLambda(0.0251) ;
 
-
-    vpTRACE("Display task information " ) ;
+    // Display task information
     task.print() ;
 
     vpTime::wait(1000); // Sleep 1s
 
-    std::cout << "\nEnter a character to continue... " <<std::endl ;
-    {    int a ; std::cin >> a ; }
-
-
     unsigned int iter=0 ;
-    vpTRACE("\t loop") ;
+    // Visual servoing loop
     unsigned int itermax ;
     if (pos==2) itermax = 75 ; else itermax = 100 ;
-    char name[FILENAME_MAX] ;
-    while(iter++<itermax)
+    while(iter++ < itermax)
     {
       double t = vpTime::measureTimeMs();
-      std::cout << "---------------------------------------------"
-                << iter <<std::endl ;
-      vpColVector v ;
 
-      if (iter==1) vpTRACE("\t\t get the robot position ") ;
+      if (iter==1) std::cout << "get the robot position" << std::endl;
       robot.getPosition(cMo) ;
-      if (iter==1) vpTRACE("\t\t new circle position ") ;
+      if (iter==1) std::cout << "new circle position" << std::endl;
       //retrieve x,y and Z of the vpCircle structure
 
       circle.track(cMo) ;
       vpFeatureBuilder::create(p,circle);
 
-      if (iter==1) vpTRACE("\t\t compute the control law ") ;
-      v = task.computeControlLaw() ;
-      //  vpTRACE("computeControlLaw" ) ;
-      std::cout << "Task rank: " << task.getTaskRank() <<std::endl ;
-      if (iter==1)
-        vpTRACE("\t\t send the camera velocity to the controller ") ;
+      if (iter==1) std::cout << "compute the control law" << std::endl;
+      vpColVector v = task.computeControlLaw() ;
+      if (iter==1) {
+        std::cout << "Task rank: " << task.getTaskRank() <<std::endl ;
+        std::cout << "send the camera velocity to the controller" << std::endl;
+      }
       robot.setVelocity(vpRobot::CAMERA_FRAME, v) ;
 
       simu->setCameraPosition(cMo) ;
 
       if(SAVE==1)
       {
+        char name[FILENAME_MAX] ;
         sprintf(name,"/tmp/image.%04d.external.png",it) ;
         std::cout << "Save " << name << std::endl ;
         simu->write(name) ;
@@ -297,22 +267,19 @@ void *mainLoop (void *_simu)
         simu->write(name) ;
         it++ ;
       }
-      //  vpTRACE("\t\t || s - s* || ") ;
+      //  std::cout << "\t\t || s - s* || "
       //  std::cout << ( task.getError() ).sumSquare() <<std::endl ; ;
       vpTime::wait(t, sampling_time * 1000); // Wait 40 ms
 
     }
     pos-- ;
     task.kill();
-
   }
 
-
   simu->closeMainApplication() ;
 
   void *a=NULL ;
   return a ;
-  // return (void *);
 }
 
 
@@ -327,10 +294,8 @@ main(int argc, const char ** argv)
     std::string username;
     bool opt_display = true;
 
-    // Get the VISP_IMAGE_PATH environment variable value
-    char *ptenv = getenv("VISP_INPUT_IMAGE_PATH");
-    if (ptenv != NULL)
-      env_ipath = ptenv;
+    // Get the visp-images-data package path or VISP_INPUT_IMAGE_PATH environment variable value
+    env_ipath = vpIoTools::getViSPImagesDataPath();
 
     // Set the default input path
     if (! env_ipath.empty())
@@ -383,7 +348,7 @@ main(int argc, const char ** argv)
       simu.addAbsoluteFrame() ;
 
       // Load the cad model
-      filename = ipath +  vpIoTools::path("/ViSP-images/iv/circle.iv");
+      filename = vpIoTools::createFilePath(ipath, "ViSP-images/iv/circle.iv");
       simu.load(filename.c_str(),fMo) ;
 
       simu.setInternalCameraParameters(cam) ;
