@@ -62,7 +62,7 @@
 #include <fstream>
 #include <sstream>
 
-#if (defined (VISP_HAVE_VIPER650) && defined (VISP_HAVE_DC1394_2))
+#if (defined (VISP_HAVE_VIPER650) && defined (VISP_HAVE_DC1394_2) && defined (VISP_HAVE_X11))
 
 #include <visp/vp1394TwoGrabber.h>
 #include <visp/vpImage.h>
