@@ -1,6 +1,6 @@
 /****************************************************************************
  *
- * $Id: vpPoseRansac.cpp 4649 2014-02-07 14:57:11Z fspindle $
+ * $Id: vpPoseRansac.cpp 5211 2015-01-26 17:44:35Z strinh $
  *
  * This file is part of the ViSP software.
  * Copyright (C) 2005 - 2014 by INRIA. All rights reserved.
@@ -37,6 +37,7 @@
  * Authors:
  * Eric Marchand
  * Aurelien Yol
+ * Souriya Trinh
  *
  *****************************************************************************/
 
@@ -46,6 +47,13 @@
   \brief function used to estimate a pose using the Ransac algorithm
 */
 
+#include <iostream>
+#include <cmath>        // std::fabs
+#include <limits>       // numeric_limits
+#include <stdlib.h>
+#include <algorithm>    // std::count
+#include <float.h>      //DBL_MAX
+
 #include <visp/vpPose.h>
 #include <visp/vpColVector.h>
 #include <visp/vpRansac.h>
@@ -53,11 +61,6 @@
 #include <visp/vpList.h>
 #include <visp/vpPoseException.h>
 
-#include <iostream>
-#include <cmath>    // std::fabs
-#include <limits>   // numeric_limits
-#include <stdlib.h>
-
 #define eps 1e-6
 
 
@@ -65,10 +68,13 @@
   Compute the pose using the Ransac approach. 
  
   \param cMo : Computed pose
+  \param func : Pointer to a function that takes in parameter a vpHomogeneousMatrix
+  and returns true if the pose check is OK or false otherwise
+  \return True if we found at least 4 points with a reprojection error below ransacThreshold.
 */
-void vpPose::poseRansac(vpHomogeneousMatrix & cMo)
+bool vpPose::poseRansac(vpHomogeneousMatrix & cMo, bool (*func)(vpHomogeneousMatrix *))
 {  
-  srand(0);
+  srand(0); //Fix seed here so we will have the same pseudo-random series at each run.
   std::vector<unsigned int> best_consensus;
   std::vector<unsigned int> cur_consensus;
   std::vector<unsigned int> cur_outliers;
@@ -90,17 +96,35 @@ void vpPose::poseRansac(vpHomogeneousMatrix & cMo)
   bool foundSolution = false;
   
   while (nbTrials < ransacMaxTrials && nbInliers < (unsigned)ransacNbInlierConsensus)
-  { 
+  {
+    //Hold the list of the index of the inliers (points in the consensus set)
+    cur_consensus.clear();
+
+    //Use a temporary variable because if not, the cMo passed in parameters will be modified when
+    // we compute the pose for the minimal sample sets but if the pose is not correct when we pass
+    // a function pointer we do not want to modify the cMo passed in parameters
+    vpHomogeneousMatrix cMo_tmp;
     cur_outliers.clear();
     cur_randoms.clear();
     
+    //Vector of used points, initialized at false for all points
     std::vector<bool> usedPt(size, false);
     
-    vpPose poseMin ;
-    for(unsigned int i = 0; i < nbMinRandom; i++)
+    vpPose poseMin;
+    for(unsigned int i = 0; i < nbMinRandom;)
     {
-      unsigned int r_ = (unsigned int)rand()%size;
-      while(usedPt[r_] ) r_ = (unsigned int)rand()%size;
+      if((size_t) std::count(usedPt.begin(), usedPt.end(), true) == usedPt.size()) {
+        //All points was picked once, break otherwise we stay in an infinite loop
+        break;
+      }
+
+      //Pick a point randomly
+      unsigned int r_ = (unsigned int) rand() % size;
+      while(usedPt[r_]) {
+        //If already picked, pick another point randomly
+        r_ = (unsigned int) rand() % size;
+      }
+      //Mark this point as already picked
       usedPt[r_] = true;
       
       std::list<vpPoint>::const_iterator iter = listP.begin();
@@ -116,91 +140,146 @@ void vpPose::poseRansac(vpHomogeneousMatrix & cMo)
           break;
         }
       }
-      if(!degenerate){
-        poseMin.addPoint(pt) ;
+      if(!degenerate) {
+        poseMin.addPoint(pt);
         cur_randoms.push_back(r_);
+        //Increment the number of points picked
+        i++;
       }
-      else
-        i--;
     }
 
-    poseMin.computePose(vpPose::LAGRANGE, cMo_lagrange) ;
-    r_lagrange = poseMin.computeResidual(cMo_lagrange) ;
-    poseMin.computePose(vpPose::DEMENTHON, cMo_dementhon) ;
-    r_dementhon = poseMin.computeResidual(cMo_dementhon) ;
-
-    if (r_lagrange < r_dementhon) {
-      r = r_lagrange;
-      cMo = cMo_lagrange;
+    if(poseMin.npt < nbMinRandom) {
+      nbTrials++;
+      continue;
     }
-    else {
-      r = r_dementhon;
-      cMo = cMo_dementhon;
+
+    //Flags set if pose computation is OK
+    bool is_valid_lagrange = false;
+    bool is_valid_dementhon = false;
+
+    //Set maximum value for residuals
+    r_lagrange = DBL_MAX;
+    r_dementhon = DBL_MAX;
+
+    try {
+      poseMin.computePose(vpPose::LAGRANGE, cMo_lagrange);
+      r_lagrange = poseMin.computeResidual(cMo_lagrange);
+      is_valid_lagrange = true;
+    } catch(/*vpException &e*/...) {
+//      std::cerr << e.what() << std::endl;
     }
-    r = sqrt(r)/(double)nbMinRandom;
 
-    if (r < ransacThreshold)
-    {
-      unsigned int nbInliersCur = 0;
-      unsigned int iter = 0;
-      for (std::list<vpPoint>::const_iterator it = listP.begin(); it != listP.end(); ++it)
-      { 
-        vpPoint pt = *it;
-        vpPoint p(pt) ;
-        p.track(cMo) ;
+    try {
+      poseMin.computePose(vpPose::DEMENTHON, cMo_dementhon);
+      r_dementhon = poseMin.computeResidual(cMo_dementhon);
+      is_valid_dementhon = true;
+    } catch(/*vpException &e*/...) {
+//      std::cerr << e.what() << std::endl;
+    }
 
-        double d = vpMath::sqr(p.get_x() - pt.get_x()) + vpMath::sqr(p.get_y() - pt.get_y()) ;
-        double error = sqrt(d) ;
-        if(error < ransacThreshold){
-          // the point is considered as inlier if the error is below the threshold
-          // But, we need also to check if it is not a degenerate point
-          bool degenerate = false;
+    //If at least one pose computation is OK,
+    //we can continue, otherwise pick another random set
+    if(is_valid_lagrange || is_valid_dementhon) {
+      if (r_lagrange < r_dementhon) {
+        r = r_lagrange;
+//        cMo = cMo_lagrange;
+        cMo_tmp = cMo_lagrange;
+      }
+      else {
+        r = r_dementhon;
+//        cMo = cMo_dementhon;
+        cMo_tmp = cMo_dementhon;
+      }
+      r = sqrt(r) / (double) nbMinRandom;
 
-          for(unsigned int it_inlier_index = 0; it_inlier_index< cur_consensus.size(); it_inlier_index++){
-            std::list<vpPoint>::const_iterator it_point = listP.begin();
-            std::advance(it_point, cur_consensus[it_inlier_index]);
-            pt = *it_point;
+      //Filter the pose using some criterion (orientation angles, translations, etc.)
+      bool isPoseValid = true;
+      if(func != NULL) {
+        isPoseValid = func(&cMo_tmp);
+        if(isPoseValid) {
+          cMo = cMo_tmp;
+        }
+      } else {
+        //No post filtering on pose, so copy cMo_temp to cMo
+        cMo = cMo_tmp;
+      }
 
-            vpPoint ptdeg = *it;
-            if( ((fabs(pt.get_x() - ptdeg.get_x()) < 1e-6) && (fabs(pt.get_y() - ptdeg.get_y()) < 1e-6))  ||
-                ((fabs(pt.get_oX() - ptdeg.get_oX()) < 1e-6) && (fabs(pt.get_oY() - ptdeg.get_oY()) < 1e-6) && (fabs(pt.get_oZ() - ptdeg.get_oZ()) < 1e-6))){
-              degenerate = true;
-              break;
+      if (isPoseValid && r < ransacThreshold)
+      {
+        unsigned int nbInliersCur = 0;
+        unsigned int iter = 0;
+        for (std::list<vpPoint>::const_iterator it = listP.begin(); it != listP.end(); ++it)
+        {
+          vpPoint pt = *it;
+          vpPoint p(pt) ;
+          p.track(cMo) ;
+
+          double d = vpMath::sqr(p.get_x() - pt.get_x()) + vpMath::sqr(p.get_y() - pt.get_y()) ;
+          double error = sqrt(d) ;
+          if(error < ransacThreshold) {
+            // the point is considered as inlier if the error is below the threshold
+            // But, we need also to check if it is not a degenerate point
+            bool degenerate = false;
+
+            for(unsigned int it_inlier_index = 0; it_inlier_index< cur_consensus.size(); it_inlier_index++){
+              std::list<vpPoint>::const_iterator it_point = listP.begin();
+              std::advance(it_point, cur_consensus[it_inlier_index]);
+              pt = *it_point;
+
+              vpPoint ptdeg = *it;
+              if( ((fabs(pt.get_x() - ptdeg.get_x()) < 1e-6) && (fabs(pt.get_y() - ptdeg.get_y()) < 1e-6))  ||
+                  ((fabs(pt.get_oX() - ptdeg.get_oX()) < 1e-6) && (fabs(pt.get_oY() - ptdeg.get_oY()) < 1e-6) && (fabs(pt.get_oZ() - ptdeg.get_oZ()) < 1e-6))){
+                degenerate = true;
+                break;
+              }
             }
-          }
 
-          if(!degenerate){
-            nbInliersCur++;
-            cur_consensus.push_back(iter);
+            if(!degenerate) {
+              nbInliersCur++;
+              cur_consensus.push_back(iter);
+            }
+            else {
+              cur_outliers.push_back(iter);
+            }
           }
           else {
             cur_outliers.push_back(iter);
           }
-        }    
-        else
-          cur_outliers.push_back(iter);
-        
-        iter++;
-      }
 
-      if(nbInliersCur > nbInliers)
-      {
-        foundSolution = true;
-        best_consensus = cur_consensus;
-        nbInliers = nbInliersCur;
+          iter++;
+        }
+
+        if(nbInliersCur > nbInliers)
+        {
+          foundSolution = true;
+          best_consensus = cur_consensus;
+          nbInliers = nbInliersCur;
+        }
+
+        nbTrials++;
+        
+        if(nbTrials >= ransacMaxTrials) {
+          vpERROR_TRACE("Ransac reached the maximum number of trials");
+          foundSolution = true;
+        }
       }
-      
+      else {
+        nbTrials++;
+
+        if(nbTrials >= ransacMaxTrials) {
+          vpERROR_TRACE("Ransac reached the maximum number of trials");
+        }
+      }
+    } else {
       nbTrials++;
-      cur_consensus.clear();
-      
-      if(nbTrials >= ransacMaxTrials){
+
+      if(nbTrials >= ransacMaxTrials) {
         vpERROR_TRACE("Ransac reached the maximum number of trials");
-        foundSolution = true;
       }
     }
   }
     
-  if(foundSolution){
+  if(foundSolution) {
     //std::cout << "Nombre d'inliers " << nbInliers << std::endl ;
     
     //Display the random picked points
@@ -219,8 +298,12 @@ void vpPose::poseRansac(vpHomogeneousMatrix & cMo)
     std::cout << std::endl;
     */
     
-    if(nbInliers >= (unsigned)ransacNbInlierConsensus)
-    {    
+    //Even if the cardinality of the best consensus set is inferior to ransacNbInlierConsensus,
+    //we want to refine the solution with data in best_consensus and return this pose.
+    //This is an approach used for example in p118 in Multiple View Geometry in Computer Vision, Hartley, R.~I. and Zisserman, A.
+    if(nbInliers >= nbMinRandom) //if(nbInliers >= (unsigned)ransacNbInlierConsensus)
+    {
+      //Refine the solution using all the points in the consensus set and with VVS pose estimation
       vpPose pose ;
       for(unsigned i = 0 ; i < best_consensus.size(); i++)
       {
@@ -231,22 +314,51 @@ void vpPose::poseRansac(vpHomogeneousMatrix & cMo)
         pose.addPoint(pt) ;
         ransacInliers.push_back(pt);
       }
-        
-      pose.computePose(vpPose::LAGRANGE, cMo_lagrange) ;
-      r_lagrange = pose.computeResidual(cMo_lagrange) ;
-      pose.computePose(vpPose::DEMENTHON, cMo_dementhon) ;
-      r_dementhon = pose.computeResidual(cMo_dementhon) ;
 
-      if (r_lagrange < r_dementhon) {
-        cMo = cMo_lagrange;
-      }
-      else {
-        cMo = cMo_dementhon;
+      //Flags set if pose computation is OK
+      bool is_valid_lagrange = false;
+      bool is_valid_dementhon = false;
+
+      //Set maximum value for residuals
+      r_lagrange = DBL_MAX;
+      r_dementhon = DBL_MAX;
+
+      try {
+        pose.computePose(vpPose::LAGRANGE, cMo_lagrange);
+        r_lagrange = pose.computeResidual(cMo_lagrange);
+        is_valid_lagrange = true;
+      } catch(/*vpException &e*/...) {
+//        std::cerr << e.what() << std::endl;
       }
 
-      pose.computePose(vpPose::VIRTUAL_VS, cMo) ;
+      try {
+        pose.computePose(vpPose::DEMENTHON, cMo_dementhon);
+        r_dementhon = pose.computeResidual(cMo_dementhon);
+        is_valid_dementhon = true;
+      } catch(/*vpException &e*/...) {
+//        std::cerr << e.what() << std::endl;
+      }
+
+      if(is_valid_lagrange || is_valid_dementhon) {
+        if (r_lagrange < r_dementhon) {
+          cMo = cMo_lagrange;
+        }
+        else {
+          cMo = cMo_dementhon;
+        }
+
+        pose.setCovarianceComputation(computeCovariance);
+        pose.computePose(vpPose::VIRTUAL_VS, cMo);
+        if(computeCovariance) {
+          covarianceMatrix = pose.covarianceMatrix;
+        }
+      }
+    } else {
+      return false;
     }
   }
+
+  return foundSolution;
 }
 
 /*!
