@@ -1,6 +1,6 @@
 /****************************************************************************
  *
- * $Id: testConversion.cpp 4658 2014-02-09 09:50:14Z fspindle $
+ * $Id: testConversion.cpp 5023 2014-12-03 16:07:48Z fspindle $
  *
  * This file is part of the ViSP software.
  * Copyright (C) 2005 - 2014 by INRIA. All rights reserved.
@@ -161,10 +161,8 @@ main(int argc, const char ** argv)
     std::string filename;
     std::string username;
 
-    // Get the VISP_IMAGE_PATH environment variable value
-    char *ptenv = getenv("VISP_INPUT_IMAGE_PATH");
-    if (ptenv != NULL)
-      env_ipath = ptenv;
+    // Get the visp-images-data package path or VISP_INPUT_IMAGE_PATH environment variable value
+    env_ipath = vpIoTools::getViSPImagesDataPath();
 
     // Set the default input path
     if (! env_ipath.empty())
@@ -192,7 +190,7 @@ main(int argc, const char ** argv)
       opath = opt_opath;
 
     // Append to the output path string, the login name of the user
-    opath += vpIoTools::path("/") + username;
+    opath = vpIoTools::createFilePath(opath, username);
 
     // Test if the output path exist. If no try to create it
     if (vpIoTools::checkDirectory(opath) == false) {
@@ -244,24 +242,24 @@ main(int argc, const char ** argv)
     //-------------------- .pgm -> .ppm
     vpTRACE("Convert a grey image (.pgm) to a color image (.ppm)");
     // Load a grey image from the disk
-    filename = ipath +  vpIoTools::path("/ViSP-images/Klimt/Klimt.pgm");
+    filename = vpIoTools::createFilePath(ipath, "ViSP-images/Klimt/Klimt.pgm");
     vpCTRACE << "Load " <<  filename << std::endl;
     vpImageIo::read(Ig, filename) ;
     // Create a color image from the grey
     vpImageConvert::convert(Ig, Ic);
-    filename = opath +  vpIoTools::path("/Klimt_color.ppm");
+    filename = vpIoTools::createFilePath(opath, "Klimt_color.ppm");
     vpCTRACE << "Write " << filename << std::endl;
     vpImageIo::write(Ic, filename) ;
 
     //-------------------- .ppm -> .pgm
     vpTRACE("Convert a color image (.ppm) to a grey image (.pgm)");
     // Load a color image from the disk
-    filename = ipath +  vpIoTools::path("/ViSP-images/Klimt/Klimt.ppm");
+    filename = vpIoTools::createFilePath(ipath, "ViSP-images/Klimt/Klimt.ppm");
     vpCTRACE << "Load " << filename << std::endl;
     vpImageIo::read(Ic, filename) ;
     // Create a grey image from the color
     vpImageConvert::convert(Ic, Ig);
-    filename = opath +  vpIoTools::path("/Klimt_grey.pgm");
+    filename = vpIoTools::createFilePath(opath, "Klimt_grey.pgm");
     vpCTRACE << "Write " << filename << std::endl;
     vpImageIo::write(Ig, filename) ;
 
@@ -274,12 +272,13 @@ main(int argc, const char ** argv)
     vpTRACE("y(%d) u(%d) v(%d) = r(%d) g(%d) b(%d)", y, u, v, r, g, b);
 
 #ifdef VISP_HAVE_OPENCV
+#if VISP_HAVE_OPENCV_VERSION < 0x020408
     double t0 = vpTime::measureTimeMs();
     /////////////////////////
     // Convert a IplImage to a vpImage<vpRGBa>
     ////////////////////////
     IplImage* image = NULL; /*!< The image read / acquired */
-    filename = ipath +  vpIoTools::path("/ViSP-images/Klimt/Klimt.ppm");
+    filename = vpIoTools::createFilePath(ipath, "ViSP-images/Klimt/Klimt.ppm");
 
     /* Read the color image */
 
@@ -290,13 +289,13 @@ main(int argc, const char ** argv)
       return (-1);
     }
     vpImageConvert::convert(image, Ic);
-    filename = opath +  vpIoTools::path("/Klimt_color_cv.ppm");
+    filename = vpIoTools::createFilePath(opath, "Klimt_color_cv.ppm");
     /* Save the the current image */
     vpImageIo::write(Ic, filename) ;
 
     vpCTRACE<< "Convert result in "<<std::endl<< filename << std::endl;
 
-    filename = ipath +  vpIoTools::path("/ViSP-images/Klimt/Klimt.pgm");
+    filename = vpIoTools::createFilePath(ipath, "ViSP-images/Klimt/Klimt.pgm");
 
     /* Read the pgm image */
 
@@ -308,7 +307,7 @@ main(int argc, const char ** argv)
       return (-1);
     }
     vpImageConvert::convert(image, Ic);
-    filename = opath +  vpIoTools::path("/Klimt_grey_cv.ppm");
+    filename = vpIoTools::createFilePath(opath, "Klimt_grey_cv.ppm");
     /* Save the the current image */
     vpImageIo::write(Ic, filename) ;
 
@@ -317,7 +316,7 @@ main(int argc, const char ** argv)
     ///////////////////////////
     // Convert a IplImage to a vpImage<unsigned char>
     ////////////////////////////
-    filename = ipath +  vpIoTools::path("/ViSP-images/Klimt/Klimt.ppm");
+    filename = vpIoTools::createFilePath(ipath, "ViSP-images/Klimt/Klimt.ppm");
 
     /* Read the color image */
 
@@ -329,13 +328,13 @@ main(int argc, const char ** argv)
       return (-1);
     }
     vpImageConvert::convert(image, Ig);
-    filename = opath +  vpIoTools::path("/Klimt_color_cv.pgm");
+    filename = vpIoTools::createFilePath(opath, "Klimt_color_cv.pgm");
     /* Save the the current image */
     vpImageIo::write(Ig, filename) ;
 
     vpCTRACE<< "Convert result in "<<std::endl<< filename << std::endl;
 
-    filename = ipath +  vpIoTools::path("/ViSP-images/Klimt/Klimt.pgm");
+    filename = vpIoTools::createFilePath(ipath, "ViSP-images/Klimt/Klimt.pgm");
 
     /* Read the pgm image */
 
@@ -348,7 +347,7 @@ main(int argc, const char ** argv)
       return (-1);
     }
     vpImageConvert::convert(image, Ig);
-    filename = opath +  vpIoTools::path("/Klimt_grey_cv.pgm");
+    filename = vpIoTools::createFilePath(opath, "Klimt_grey_cv.pgm");
     /* Save the the current image */
     vpImageIo::write(Ig, filename) ;
 
@@ -357,7 +356,7 @@ main(int argc, const char ** argv)
     ////////////////////////////////////
     // Convert a vpImage<vpRGBa> to a IplImage
     ////////////////////////////////////
-    filename = ipath +  vpIoTools::path("/ViSP-images/Klimt/Klimt.ppm");
+    filename = vpIoTools::createFilePath(ipath, "ViSP-images/Klimt/Klimt.ppm");
 
     /* Read the color image */
 
@@ -365,7 +364,7 @@ main(int argc, const char ** argv)
     vpCTRACE << "Load " << filename << std::endl;
     vpImageIo::read(Ic, filename) ;
     vpImageConvert::convert(Ic, image);
-    filename = opath +  vpIoTools::path("/Klimt_ipl_color_cv.ppm");
+    filename = vpIoTools::createFilePath(opath, "Klimt_ipl_color_cv.ppm");
     /* Save the the current image */
     vpCTRACE << "Write " << filename << std::endl;
     if((cvSaveImage(filename.c_str(), image)) == 0) {
@@ -378,7 +377,7 @@ main(int argc, const char ** argv)
     ////////////////////////////////////////
     // Convert a IplImage to a vpImage<unsigned char>
     ////////////////////////////////////////
-    filename = ipath +  vpIoTools::path("/ViSP-images/Klimt/Klimt.pgm");
+    filename = vpIoTools::createFilePath(ipath, "ViSP-images/Klimt/Klimt.pgm");
 
     /* Read the grey image */
 
@@ -386,7 +385,7 @@ main(int argc, const char ** argv)
     vpCTRACE << "Load " << filename << std::endl;
     vpImageIo::read(Ig, filename) ;
     vpImageConvert::convert(Ig, image);
-    filename = opath +  vpIoTools::path("/Klimt_ipl_grey_cv.pgm");
+    filename = vpIoTools::createFilePath(opath, "Klimt_ipl_grey_cv.pgm");
     /* Save the the current image */
 
     vpCTRACE << "Write " << filename << std::endl;
@@ -400,6 +399,7 @@ main(int argc, const char ** argv)
     if(image!=NULL) cvReleaseImage( &image );
     double t1 = vpTime::measureTimeMs();
     std::cout << "Conversion c interface : " << t1 - t0 << " ms" << std::endl;
+#endif
 
     /* ------------------------------------------------------------------------ */
     /*                  conversion for the new c++ interface                    */
@@ -411,7 +411,7 @@ main(int argc, const char ** argv)
     // Convert a cv::Mat to a vpImage<vpRGBa>
     ////////////////////////
     cv::Mat imageMat;
-    filename = ipath +  vpIoTools::path("/ViSP-images/Klimt/Klimt.ppm");
+    filename = vpIoTools::createFilePath(ipath, "ViSP-images/Klimt/Klimt.ppm");
     vpCTRACE << "Reading the color image with c++ interface of opencv: "<< std::endl
              << filename << std::endl;
     imageMat = cv::imread(filename, 1);// force to a three channel color image.
@@ -420,12 +420,12 @@ main(int argc, const char ** argv)
       return -1;
     }
     vpImageConvert::convert(imageMat, Ic);
-    filename = opath +  vpIoTools::path("/Klimt_color_cvMat.ppm");
+    filename = vpIoTools::createFilePath(opath, "Klimt_color_cvMat.ppm");
     /* Save the the current image */
     vpImageIo::write(Ic, filename) ;
     vpCTRACE<< "Convert result in "<<std::endl<< filename << std::endl;
 
-    filename = ipath +  vpIoTools::path("/ViSP-images/Klimt/Klimt.pgm");
+    filename = vpIoTools::createFilePath(ipath, "ViSP-images/Klimt/Klimt.pgm");
     /* Read the pgm image */
 
     vpCTRACE << "Reading the greyscale image with opencv: "<< std::endl
@@ -436,7 +436,7 @@ main(int argc, const char ** argv)
       return (-1);
     }
     vpImageConvert::convert(imageMat, Ic);
-    filename = opath +  vpIoTools::path("/Klimt_grey_cvMat.ppm");
+    filename = vpIoTools::createFilePath(opath, "Klimt_grey_cvMat.ppm");
     /* Save the the current image */
     vpImageIo::write(Ic, filename) ;
     vpCTRACE<< "Convert result in "<<std::endl<< filename << std::endl;
@@ -444,7 +444,7 @@ main(int argc, const char ** argv)
     ///////////////////////////
     // Convert a cv::Mat to a vpImage<unsigned char>
     ////////////////////////////
-    filename = ipath +  vpIoTools::path("/ViSP-images/Klimt/Klimt.ppm");
+    filename = vpIoTools::createFilePath(ipath, "ViSP-images/Klimt/Klimt.ppm");
 
     /* Read the color image */
 
@@ -456,12 +456,12 @@ main(int argc, const char ** argv)
       return -1;
     }
     vpImageConvert::convert(imageMat, Ig);
-    filename = opath +  vpIoTools::path("/Klimt_color_cvMat.pgm");
+    filename = vpIoTools::createFilePath(opath, "Klimt_color_cvMat.pgm");
     /* Save the the current image */
     vpImageIo::write(Ig, filename) ;
     vpCTRACE<< "Convert result in "<<std::endl<< filename << std::endl;
 
-    filename = ipath +  vpIoTools::path("/ViSP-images/Klimt/Klimt.pgm");
+    filename = vpIoTools::createFilePath(ipath, "ViSP-images/Klimt/Klimt.pgm");
 
     /* Read the pgm image */
 
@@ -473,7 +473,7 @@ main(int argc, const char ** argv)
       return (-1);
     }
     vpImageConvert::convert(imageMat, Ig);
-    filename = opath +  vpIoTools::path("/Klimt_grey_cvMat.pgm");
+    filename = vpIoTools::createFilePath(opath, "Klimt_grey_cvMat.pgm");
     /* Save the the current image */
     vpImageIo::write(Ig, filename) ;
 
@@ -482,7 +482,7 @@ main(int argc, const char ** argv)
     ////////////////////////////////////
     // Convert a vpImage<vpRGBa> to a cv::Mat
     ////////////////////////////////////
-    filename = ipath +  vpIoTools::path("/ViSP-images/Klimt/Klimt.ppm");
+    filename = vpIoTools::createFilePath(ipath, "ViSP-images/Klimt/Klimt.ppm");
 
     /* Read the color image */
 
@@ -490,12 +490,11 @@ main(int argc, const char ** argv)
     vpCTRACE << "Load " << filename << std::endl;
     vpImageIo::read(Ic, filename) ;
     vpImageConvert::convert(Ic, imageMat);
-    filename = opath +  vpIoTools::path("/Klimt_ipl_color_cvMat.ppm");
+    filename = vpIoTools::createFilePath(opath, "Klimt_ipl_color_cvMat.ppm");
     /* Save the the current image */
     vpCTRACE << "Write " << filename << std::endl;
     if(!cv::imwrite(filename, imageMat)){
       vpCTRACE<<"Cannot write image: "<< std::endl << filename << std::endl;
-      if(image!=NULL) cvReleaseImage( &image );
       return (-1);
     }
     vpCTRACE<< "Convert result in "<<std::endl<< filename << std::endl;
@@ -503,7 +502,7 @@ main(int argc, const char ** argv)
     ////////////////////////////////////////
     // Convert a IplImage to a vpImage<unsigned char>
     ////////////////////////////////////////
-    filename = ipath +  vpIoTools::path("/ViSP-images/Klimt/Klimt.pgm");
+    filename = vpIoTools::createFilePath(ipath, "ViSP-images/Klimt/Klimt.pgm");
 
     /* Read the grey image */
 
@@ -511,13 +510,12 @@ main(int argc, const char ** argv)
     vpCTRACE << "Load " << filename << std::endl;
     vpImageIo::read(Ig, filename);
     vpImageConvert::convert(Ig, imageMat);
-    filename = opath +  vpIoTools::path("/Klimt_ipl_grey_cvMat.pgm");
+    filename = vpIoTools::createFilePath(opath, "Klimt_ipl_grey_cvMat.pgm");
     /* Save the the current image */
 
     vpCTRACE << "Write " << filename << std::endl;
     if(!cv::imwrite(filename, imageMat)){
       vpCTRACE<<"Cannot write image: "<< std::endl << filename << std::endl;
-      if(image!=NULL) cvReleaseImage( &image );
       return (-1);
     }
     vpCTRACE<< "Convert result in "<<std::endl<< filename << std::endl;
@@ -529,7 +527,7 @@ main(int argc, const char ** argv)
     ////////////////////////////////////
     // Split a vpImage<vpRGBa> to vpImage<unsigned char>
     ////////////////////////////////////
-    filename = ipath +  vpIoTools::path("/ViSP-images/Klimt/Klimt.ppm");
+    filename = vpIoTools::createFilePath(ipath, "ViSP-images/Klimt/Klimt.ppm");
 
     /* Read the color image */
 
@@ -546,13 +544,13 @@ main(int argc, const char ** argv)
 
     std::cout<<"Time for 1000 split (ms): "<< endtime - begintime <<std::endl;
 
-    filename = opath +  vpIoTools::path("/Klimt_RChannel.pgm");
+    filename = vpIoTools::createFilePath(opath, "Klimt_RChannel.pgm");
     /* Save the the current image */
     vpCTRACE << "Write " << filename << std::endl;
     vpImageIo::write(R, filename) ;
     vpCTRACE<< "Convert result in "<<std::endl<< filename << std::endl;
 
-    filename = opath +  vpIoTools::path("/Klimt_BChannel.pgm");
+    filename =  vpIoTools::createFilePath(opath, "Klimt_BChannel.pgm");
     /* Save the the current image */
     vpCTRACE << "Write " << filename << std::endl;
     vpImageIo::write(B, filename) ;
